﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using Xamarin.Forms;

namespace TVMediaHub.Tizen.Controls
{
    /// <summary>
    /// A custom ContentPage for Image tab and Video tab of MediaHub
    /// </summary>
    public abstract class ContentPageEx : ContentPage
    {
        /// <summary>
        /// Gets or sets EventHandler for handling back button
        /// </summary>
        protected EventHandler OnBackButtonPressedHandler { set; get; }

        /// <summary>
        /// A constructor
        /// Adds or removes a back button to page
        /// Sets a value that indicates whether or not this NavigationPage element has a navigation bar
        /// </summary>
        protected ContentPageEx()
            : base()
        {
            NavigationPage.SetHasBackButton(this, false);
            NavigationPage.SetHasNavigationBar(this, false);
        }

        /// <summary>
        /// This method is called when the page becoming visible.
        /// </summary>
        protected override void OnAppearing()
        {
            base.OnAppearing();
            InitializePage();
        }

        /// <summary>
        /// This method is callend when the page is disappeared.
        /// </summary>
        protected override void OnDisappearing()
        {
            base.OnDisappearing();
            FinalizePage();
            GC.Collect();
        }

        /// <summary>
        /// This method is called when Back button is pressed
        /// </summary>
        /// <returns>Always returns true</returns>
        protected override bool OnBackButtonPressed()
        {
            if (OnBackButtonPressedHandler != null)
            {
                OnBackButtonPressedHandler.Invoke(this, EventArgs.Empty);
                return true;
            }

            Program.TransitionToMain();
            return true;
        }

        /// <summary>
        /// A method for initializing page when the page is appeared
        /// </summary>
        protected abstract void InitializePage();

        /// <summary>
        /// A method for finalizing page when the page is disappeared
        /// </summary>
        protected abstract void FinalizePage();

        /// <summary>
        /// A method for running hide animation
        /// </summary>
        public abstract void RunHideAnimation();

        /// <summary>
        /// A method for running show animation
        /// </summary>
        public abstract void RunShowAnimation();
    }
}
