﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Windows.Input;
using Xamarin.Forms;

namespace TVMediaHub.Tizen.Controls
{
    /// <summary>
    /// A custom image for displaying the buttons of image viewer
    /// </summary>
    public partial class ZoomNaviButton : Image
    {
        /// <summary>
        /// An event handler to notify if the button is up
        /// </summary>
        public event EventHandler<string> OnButtonUp;

        /// <summary>
        /// An event handler to notify if the button is down
        /// </summary>
        public event EventHandler<string> OnButtonDown;

        /// <summary>
        /// An event handler to notify if the button is clicked
        /// </summary>
        public event EventHandler Clicked;

        /// <summary>
        /// A prefix of the navigation button image
        /// </summary>
        private string imgZoomPrefix = "ic_zoom_arrow_";

        /// <summary>
        /// A postfix of the navigation button image on normal status
        /// </summary>
        private string imgNormalPostFix = "_normal.png";

        /// <summary>
        /// A postfix of the navigation button image on pressed status
        /// </summary>
        private string imgPressedPostFix = "_pressed.png";

        /// <summary>
        /// Gets or sets the button type
        /// </summary>
        public string Type
        {
            get;
            set;
        }

        /// <summary>
        /// A command will be executed if the button image is tapped
        /// </summary>
        public ICommand TapGestureCommand
        {
            get;
            set;
        }

        /// <summary>
        /// A method for handling the actions when the button is pressed.
        /// </summary>
        public void OnButtonPressed()
        {
            Source = imgZoomPrefix + Type.ToLower() + imgPressedPostFix;

            OnButtonDown?.Invoke(this, Type);
        }

        /// <summary>
        /// A method for handling the actions when the button is released.
        /// </summary>
        public void OnButtonReleased()
        {
            Source = imgZoomPrefix + Type.ToLower() + imgNormalPostFix;

            OnButtonUp?.Invoke(this, Type);
        }

        /// <summary>
        /// A constructor
        /// Implements the TapGestureCommand
        /// </summary>
        public ZoomNaviButton()
        {
            InitializeComponent();

            TapGestureCommand = new Command(() =>
            {
                Clicked?.Invoke(this, EventArgs.Empty);
            });
        }
    }
}
