﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using Xamarin.Forms.Platform.Tizen;
using TVMediaHub.Tizen.Controls;

[assembly: ExportRenderer(typeof(ZoomNaviButton), typeof(ZoomNaviButtonRenderer))]
namespace TVMediaHub.Tizen.Controls
{
    /// <summary>
    /// A custom renderer for making custom image button.
    /// </summary>
    public class ZoomNaviButtonRenderer : ImageRenderer
    {
        private ElmSharp.GestureLayer GestureRecognizer;

        /// <summary>
        /// Creates GestureRecognizer and sets callbacks for tap and long tap event when Element is changed.
        /// </summary>
        /// <param name="args">An image element property changed event's argument</param>
        protected override void OnElementChanged(ElementChangedEventArgs<Xamarin.Forms.Image> args)
        {
            base.OnElementChanged(args);

            if (Control == null || Element == null)
            {
                return;
            }

            if (GestureRecognizer == null)
            {
                GestureRecognizer = new ElmSharp.GestureLayer(Control);
                GestureRecognizer.Attach(Control);
            }

            ZoomNaviButton BtnElement = Element as ZoomNaviButton;
            if (BtnElement == null)
            {
                return;
            }

            GestureRecognizer.SetTapCallback(ElmSharp.GestureLayer.GestureType.Tap, ElmSharp.GestureLayer.GestureState.Start, x =>
            {
               BtnElement.OnButtonPressed();
            });

            GestureRecognizer.SetTapCallback(ElmSharp.GestureLayer.GestureType.Tap, ElmSharp.GestureLayer.GestureState.End, x =>
            {
                BtnElement.OnButtonReleased();
                BtnElement.TapGestureCommand?.Execute(null);
            });

            GestureRecognizer.SetTapCallback(ElmSharp.GestureLayer.GestureType.LongTap, ElmSharp.GestureLayer.GestureState.Start, x =>
            {
                BtnElement.OnButtonPressed();
            });

            GestureRecognizer.SetTapCallback(ElmSharp.GestureLayer.GestureType.LongTap, ElmSharp.GestureLayer.GestureState.End, x =>
            {
                BtnElement.OnButtonReleased();
            });

            Control.RepeatEvents = true;
        }
    }
}
