﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.IO;
using TVMediaHub.Tizen.Utils;
using TVMediaHub.Tizen.DataModels;

namespace TVMediaHub.Tizen.Models
{
    /// <summary>
    /// A custom ContentProvider for image contents
    /// </summary>
    public class ImageProvider : ContentProvider
    {
        /// <summary>
        /// A constructor
        /// </summary>
        public ImageProvider() : base()
        {
        }

        /// <summary>
        /// A method for getting condition for selection query
        /// </summary>
        /// <returns>A condition string</returns>
        protected override string GetConditionStringForSelection()
        {
            return "(MEDIA_TYPE=0) AND (MEDIA_MIME_TYPE LIKE 'image%') AND NOT (MEDIA_PATH LIKE '%.tn')";
        }

        /// <summary>
        /// A method to determine the availability of the content.
        /// </summary>
        /// <param name="mediaContent">A media content to be checked the availability</param>
        protected override void CheckUnavailableContent(MediaInformationEx mediaContent)
        {
            if (mediaContent.MediaContentInformation.Path != null)
            {
                // Check 1 : The size of the image file must be less than 4MB.
                var fileInfo = new FileInfo(mediaContent.MediaContentInformation.Path);

                if (fileInfo?.Length > 8 * 1024 * 1024)
                {
                    DbgPort.D(mediaContent.MediaContentInformation.DisplayName + ": This content is not available");
                    mediaContent.IsAvailable = false;
                }
            }
        }

        public override void SetContentUpdatedEventListener(EventHandler listener)
        {
            base.ContentUpdateFinished += listener;
        }
    }
}
