﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


using Tizen.Content.MediaContent;

namespace TVMediaHub.Tizen.Models
{
    /// <summary>
    /// A main instance class of the TVMediaHub to providing the Model functions.
    /// </summary>
    public sealed class MediaHubImpl
    {
        /// <summary>
        /// An instance of the MediaHubImpl
        /// </summary>
        private static readonly MediaHubImpl instance = new MediaHubImpl();

        /// <summary>
        /// Gets an instance of the MediaHubImpl
        /// </summary>
        public static MediaHubImpl GetInstance
        {
            get
            {
                return instance;
            }
        }

        /// <summary>
        /// An instance of the ImageProvider
        /// </summary>
        private static readonly ImageProvider imageProviderInstance = new ImageProvider();
        /// <summary>
        /// Gets an instance of the ImageProvider
        /// </summary>
        public ImageProvider ImageProviderInstance
        {
            get
            {
                return imageProviderInstance;
            }
        }

        /// <summary>
        /// An instance of the MusicProvider
        /// </summary>
        private static readonly MusicProvider musicProviderInstance = new MusicProvider();

        /// <summary>
        /// Gets an instance of the MusicProvider
        /// </summary>
        public MusicProvider MusicProviderInstance
        {
            get
            {
                return musicProviderInstance;
            }
        }

        /// <summary>
        /// An instance of the MusicProvider
        /// </summary>
        private static readonly VideoProvider videoProviderInstance = new VideoProvider();

        /// <summary>
        /// Gets an instance of the MusicProvider
        /// </summary>
        public VideoProvider VideoProviderInstance
        {
            get
            {
                return videoProviderInstance;
            }
        }

        /// <summary>
        /// An instance of the StorageProvider
        /// </summary>
        private static readonly StorageProvider storageProviderInstance = new StorageProvider();

        /// <summary>
        /// Gets an instance of the StorageProvider
        /// </summary>
        public StorageProvider StorageProviderInstance
        {
            get
            {
                return storageProviderInstance;
            }
        }

        private MediaDatabase mediaDatabase ;

        public MediaDatabase MediaDatabase
        {
            get
            {
                if (mediaDatabase == null)
                {
                    mediaDatabase = new MediaDatabase();
                    mediaDatabase.Connect();
                }
                return mediaDatabase;
            }
        }

        private static MediaInfoCommand mediaInfoCommand;

        public MediaInfoCommand MediaInfoCommand
        {
            get
            {
                if (mediaInfoCommand == null)
                {
                    mediaInfoCommand = new MediaInfoCommand(MediaDatabase);
                }
                return mediaInfoCommand;
            }
        }

        private static StorageCommand storageCommand;

        public StorageCommand StorageCommand
        {
            get
            {
                if (storageCommand == null)
                {
                    storageCommand = new StorageCommand(MediaDatabase);
                }
                return storageCommand;
            }
        }

        /// <summary>
        /// A constructor
        /// </summary>
        public MediaHubImpl()
        {

        }
    }
}
