﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System.ComponentModel;
using TVMediaHub.Tizen.DataModels;
using Tizen.Content.MediaContent;
using TVMediaHub.Tizen.ViewModels;

namespace TVMediaHub.Tizen.Models
{
    /// <summary>
    /// The MediaShortcutInfo is model for media information of the represented object.
    /// </summary>
    public class MediaShortcutInfo : INotifyPropertyChanged
    {
        /// <summary>
        /// An event handler for handling property changed.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// A method for notifying property changed event.
        /// </summary>
        /// <param name="name">The name of property</param>
        public void OnPropertyChanged(string name)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(name));
            }
        }

        /// <summary>
        /// An enumeration value indicates current tab's status
        /// </summary>
        private TabStatus currentTabStatus = TabStatus.Default;
        /// <summary>
        /// Gets or sets the CurrentTabStatus
        /// </summary>
        public TabStatus CurrentTabStatus
        {
            get
            {
                return currentTabStatus;
            }

            set
            {
                if (currentTabStatus != value)
                {
                    currentTabStatus = value;
                    OnPropertyChanged("CurrentTabStatus");
                }
            }
        }

        /// <summary>
        /// Gets or sets the MediaInformationEx object
        /// </summary>
        public MediaInformationEx Information { protected set; get; }

        /// <summary>
        /// Gets or sets the content's thumbnail path
        /// </summary>
        public string ThumbnailPath
        {
            get
            {
                if (Information.MediaContentInformation.ThumbnailPath == null)
                {
                    return Information.MediaContentInformation.Path + ".tn";
                }
                else
                {
                    return Information.MediaContentInformation.ThumbnailPath;
                }
            }
        }

        /// <summary>
        /// Gets or sets the content's title
        /// </summary>
        public string ContentName
        {
            get { return Information.MediaContentInformation.Title; }
        }

        /// <summary>
        /// A constructor
        /// </summary>
        /// <param name="information">A MediaInformationEx to be MediaShortcutInfo's data</param>
        public MediaShortcutInfo(MediaInformationEx information)
        {
            Information = information;
            CurrentTabStatus = TabStatus.Default;
        }

        /// <summary>
        /// A method for calling OnPropertyChanged of ThumnailPath property.
        /// </summary>
        public void Update()
        {
            OnPropertyChanged("ThumbnailPath");
        }
    }
}
