﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;
using Tizen.Content.MediaContent;
using TVMediaHub.Tizen.Utils;
using TVMediaHub.Tizen.DataModels;

namespace TVMediaHub.Tizen.Models
{
    /// <summary>
    /// A custom ContentProvider for video contents
    /// </summary>
    public class VideoProvider : ContentProvider
    {
        /// <summary>
        /// A constructor
        /// </summary>
        public VideoProvider() : base()
        {
        }

        /// <summary>
        /// A method for getting condition for selection query
        /// </summary>
        /// <returns>A condition string</returns>
        protected override string GetConditionStringForSelection()
        {
            // TODO : fix this, currently VD GBM media scan recognize .ts file as text/xxxx
            return "(MEDIA_TYPE=1) AND (MEDIA_MIME_TYPE LIKE 'video%' OR MEDIA_MIME_TYPE LIKE 'text%') ";
        }

        /// <summary>
        /// A method to determine the availability of the content.
        /// </summary>
        /// <param name="mediaContent">A media content to be checked the availability</param>
        protected override void CheckUnavailableContent(MediaInformationEx mediaContent)
        {
            // TODO : Add unsupported mime type here
            if (mediaContent.MediaContentInformation.IsDrm ||
                mediaContent.MediaContentInformation.MimeType.Contains("ogg"))
            {
                DbgPort.D(mediaContent.MediaContentInformation.DisplayName + " : This content is not available");
                mediaContent.IsAvailable = false;
            }
        }

        public override void SetContentUpdatedEventListener(EventHandler listener)
        {
            base.ContentUpdateFinished += listener;
        }
    }
}