/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using Tizen.Applications;
using Tizen.Xamarin.Forms.Extension.Renderer;
using Xamarin.Forms;
using TVMediaHub.Tizen.Views;
using TVMediaHub.Tizen.ViewModels;

namespace TVMediaHub.Tizen
{
    /// <summary>
    /// TV MediaHub application main entry point
    /// </summary>
    class Program : global::Xamarin.Forms.Platform.Tizen.FormsApplication
    {
        /// <summary>
        /// Gets or sets the instance of TV MediaHub
        /// </summary>
        public static Program Instance
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets or sets the resource directory path of TV MediaHub
        /// </summary>
        public static string ResourceDirectoryPath
        {
            get;
            private set;
        }

        /// <summary>
        /// An instance of the TV MediaHub application
        /// </summary>
        private static App app;

        /// <summary>
        /// A method will be called when application is created
        /// </summary>
        protected override void OnCreate()
        {
            base.OnCreate();

            // TODO : due to VD's GBM binary issue.
            if (DirectoryInfo.Resource == null || DirectoryInfo.Resource.Length < 1)
            {
                ResourceDirectoryPath = "/home/owner/apps_rw/org.tizen.xamediahub/res/";
            }
            else
            {
                ResourceDirectoryPath = DirectoryInfo.Resource;
            }

            app = new App(MainWindow.ScreenSize.Width,
                MainWindow.ScreenSize.Height,
                MainWindow.ScreenDpi.X,
                ElmSharp.Elementary.GetScale(),
                MainWindow);
            LoadApplication(app);
        }

        /// <summary>
        /// A method will be called when application receives app control
        /// </summary>
        /// <param name="e">AppControl event argument</param>
        protected override void OnAppControlReceived(AppControlReceivedEventArgs e)
        {
            if (e.ReceivedAppControl != null && e.ReceivedAppControl.ExtraData != null)
            {
                string mediaId;
                if (e.ReceivedAppControl.ExtraData.TryGet("Media Id", out mediaId) == true)
                {
                    VideoTabViewModelLocator.ViewModel.SetCurrentVideo(mediaId);
                    Program.TransitionTo(new VideoPlayer());
                }
            }
        }

        /// <summary>
        /// A method for pushing a specific page to navigation stack.
        /// </summary>
        /// <param name="page">A page to be pushed</param>
        public static void TransitionTo(ContentPage page)
        {
            app.TransitionTo(page);
        }

        /// <summary>
        /// A method for setting the root page as MainPage.
        /// </summary>
        /// <param name="tabIndex">An index of tab to be set as MainPage. Default value is 0</param>
        public static void TransitionToMain(int tabIndex = 0)
        {
            app.TransitionToMain(tabIndex);
        }

        /// <summary>
        /// The entry point for the application
        /// </summary>
        /// <param name="args">A list of command line arguments</param>
        static void Main(string[] args)
        {
            Instance = new Program();
            TizenFormsExtension.Init();
            global::Xamarin.Forms.Platform.Tizen.Forms.Init(Instance);
            Instance.Run(args);
        }

        /// <summary>
        /// A method terminates application
        /// </summary>
        public void SelfTerminate()
        {
            Instance.Exit();
        }
    }
}
