/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using Tizen;
using System.Runtime.CompilerServices;
using System;

namespace TVMediaHub.Tizen.Utils
{
    /// <summary>
    /// Platform dependent implementation for the Logging.
    /// </summary>
    public class DbgPort
    {
        /// <summary>
        /// A Logging Tag
        /// </summary>
        public static readonly string TAG = "mediahub";

        /// <summary>
        /// A flag which enables console log writting
        /// </summary>
        private static readonly bool IsNeedToShowInConsole = true;

        /// <summary>
        /// Displays a log message which developer want to check
        /// </summary>
        /// <param name="message"> A debugging message </param>
        /// <param name="file"> A file name that debugging message is exist </param>
        /// <param name="func"> A function name that debugging message is exist </param>
        /// <param name="line"> A line number that debugging message is exist </param>
        public static void D(string message, [CallerFilePath] System.String file = "", [CallerMemberName] System.String func = "", [CallerLineNumber] System.Int32 line = 0)
        {
            Log.Debug(TAG, message, file, func, line);
            if (IsNeedToShowInConsole)
            {
                Console.WriteLine(String.Format("{0}, {1}:{2},{3}", message, file.Substring(file.LastIndexOf("\\")), line, func));
            }
        }

        /// <summary>
        /// Displays an error log message
        /// </summary>
        /// <param name="message"> A debugging message </param>
        /// <param name="file"> A file name that debugging message is exist </param>
        /// <param name="func"> A function name that debugging message is exist </param>
        /// <param name="line"> A line number that debugging message is exist </param>
        public static void E(string message, [CallerFilePath] System.String file = "", [CallerMemberName] System.String func = "", [CallerLineNumber] System.Int32 line = 0)
        {
            Log.Error(TAG, message, file, func, line);
            if (IsNeedToShowInConsole)
            {
                Console.WriteLine(String.Format("{0}, {1}:{2},{3}", message, file.Substring(file.LastIndexOf("\\")), line, func));
            }
        }
    }
}