﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System.Runtime.CompilerServices;

namespace TVMediaHub.Tizen.Utils
{
    /// <summary>
    /// A class to display a log message which developer want to check
    /// </summary>
    public class InOutDbgRAII
    {
        /// <summary>
        /// A function name that debugging message is exist
        /// </summary>
        private string function;
        /// <summary>
        /// A file name that debugging message is exist
        /// </summary>
        private string fileName;

        /// <summary>
        /// Displays a log message which developer want to check
        /// </summary>
        /// <param name="file">A file name that debugging message is exist</param>
        /// <param name="func">A function name that debugging message is exist</param>
        public InOutDbgRAII([CallerFilePath] System.String file = "", [CallerMemberName] System.String func = "")
        {
            function = func;
            int idx = file.LastIndexOf("\\") + 1;
            fileName = file.Substring(idx, file.Length - idx);

            DbgPort.D("[>>>] " + function + ", " + fileName, "", "InOut");
        }

        // This is only for the debugging purpose, due to performance issue.
        ~InOutDbgRAII()
        {
            DbgPort.D("[<<<] " + function + ", " + fileName, "", "InOut");
        }
    }
}
