﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using Xamarin.Forms;

namespace TVMediaHub.Tizen.Utils
{
    /// <summary>
    /// A custom control for displaying nine patch image
    /// </summary>
    public partial class NinePatch : Image
    {
        /// <summary>
        /// Identifies the BorderLeft bindable property
        /// </summary>
        public static readonly BindableProperty BorderLeftProperty = BindableProperty.Create("BorderLeft", typeof(int), typeof(NinePatch), default(int));

        /// <summary>
        /// Gets or sets left border of NinePatchImage
        /// </summary>
        public int BorderLeft
        {
            get { return (int)GetValue(BorderLeftProperty); }
            set { SetValue(BorderLeftProperty, value); }
        }

        /// <summary>
        /// Identifies the BorderRight bindable property
        /// </summary>
        public static readonly BindableProperty BorderRightProperty = BindableProperty.Create("BorderRight", typeof(int), typeof(NinePatch), default(int));

        /// <summary>
        /// Gets or sets right border of NinePatchImage
        /// </summary>
        public int BorderRight
        {
            get { return (int)GetValue(BorderRightProperty); }
            set { SetValue(BorderRightProperty, value); }
        }

        /// <summary>
        /// Identifies the BorderTop bindable property
        /// </summary>
        public static readonly BindableProperty BorderTopProperty = BindableProperty.Create("BorderTop", typeof(int), typeof(NinePatch), default(int));

        /// <summary>
        /// Gets or sets top border of NinePatchImage
        /// </summary>
        public int BorderTop
        {
            get { return (int)GetValue(BorderTopProperty); }
            set { SetValue(BorderTopProperty, value); }
        }

        /// <summary>
        /// Identifies the BorderBottom bindable property
        /// </summary>
        public static readonly BindableProperty BorderBottomProperty = BindableProperty.Create("BorderBottom", typeof(int), typeof(NinePatch), default(int));

        /// <summary>
        /// Gets or sets bottom border of NinePatchImage
        /// </summary>
        public int BorderBottom
        {
            get { return (int)GetValue(BorderBottomProperty); }
            set { SetValue(BorderBottomProperty, value); }
        }

        /// <summary>
        /// Identifies the ImageColor bindable property
        /// </summary>
        public static readonly BindableProperty ImageColorProperty = BindableProperty.Create("ImageColor", typeof(Color), typeof(NinePatch), Color.Black);

        /// <summary>
        /// Gets or sets ImageColor of NinePatchImage
        /// </summary>
        public Color ImageColor
        {
            get { return (Color)GetValue(ImageColorProperty); }
            set { SetValue(ImageColorProperty, value); }
        }

        /// <summary>
        /// A constructor
        /// </summary>
        public NinePatch()
        {
            InitializeComponent();
        }
    }
}
