﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.ComponentModel;
using TVMediaHub.Tizen.Utils;
using Xamarin.Forms.Platform.Tizen;

[assembly: ExportRenderer(typeof(NinePatch), typeof(NinePatchRenderer))]
namespace TVMediaHub.Tizen.Utils
{
    /// <summary>
    /// A custom renderer for NinePatchImage
    /// </summary>
    /// <see cref="NinePatch"/>
    class NinePatchRenderer : ImageRenderer
    {
        /// <summary>
        /// Updates border when Element is changed
        /// </summary>
        /// <param name="args">An image element changed event's argument </param>
        protected override void OnElementChanged(ElementChangedEventArgs<Xamarin.Forms.Image> args)
        {
            base.OnElementChanged(args);
            UpdateBorder();
        }

        /// <summary>
        /// Updates border when ElementProperty is changed
        /// </summary>
        /// <param name="sender">The source of the event</param>
        /// <param name="args">An image element property changed event's argument </param>
        protected override void OnElementPropertyChanged(object sender, PropertyChangedEventArgs args)
        {
            if ((args.PropertyName == NinePatch.BorderBottomProperty.PropertyName)
                || (args.PropertyName == NinePatch.BorderLeftProperty.PropertyName)
                || (args.PropertyName == NinePatch.BorderRightProperty.PropertyName)
                || (args.PropertyName == NinePatch.BorderTopProperty.PropertyName))
            {
                UpdateBorder();
            }
            else if (args.PropertyName == NinePatch.ImageColorProperty.PropertyName)
            {
                UpdateImageColor();
            }

            base.OnElementPropertyChanged(sender, args);
        }

        /// <summary>
        /// A method for updating image color of Control
        /// </summary>
        private void UpdateImageColor()
        {
            var img = Element as NinePatch;
            if (Control != null)
            {
                Control.Color = new ElmSharp.Color(Convert.ToInt32(img.ImageColor.R * 255), Convert.ToInt32(img.ImageColor.G * 255), Convert.ToInt32(img.ImageColor.B * 255), Convert.ToInt32(img.ImageColor.A * 255));
            }
        }

        /// <summary>
        /// A method updates border of Control(Native Image)
        /// </summary>
        void UpdateBorder()
        {
            var img = Element as NinePatch;
            Control?.SetBorder(img.BorderLeft, img.BorderRight, img.BorderTop, img.BorderBottom);
        }

        /// <summary>
        /// A method updates border of Control(Native Image) after loading
        /// </summary>
        protected override void UpdateAfterLoading()
        {
            base.UpdateAfterLoading();
            UpdateBorder();
            UpdateImageColor();
        }
    }
}
