﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System.Runtime.InteropServices;


namespace TVMediaHub.Tizen.Utils
{
    /// <summary>
    /// Handles SystemInfo APIs
    /// </summary>
    public class SystemSettingsPort
    {
        /// <summary>
        /// A value to check whether error is exist or not
        /// </summary>
        public static readonly int ErrorNone = 0;
        /// <summary>
        /// A privilege for get the device model name
        /// </summary>
        public static readonly string KeyModelName = "http://tizen.org/system/model_name";

        /// <summary>
        /// A class for handling SystemInfo APIs
        /// </summary>
        internal class SystemInfo
        {
            [DllImport("libcapi-system-info.so.0", EntryPoint = "system_info_get_platform_string", CallingConvention = CallingConvention.Cdecl)]
            internal static extern int SystemInfoGetPlatformString(string key, out string value);
        }

        /// <summary>
        /// A method for getting device model name
        /// </summary>
        /// <param name="modelName">A device model name</param>
        /// <returns>A value to check whether error is exist or not</returns>
        public static bool GetSystemModelName(out string modelName)
        {
            if (SystemInfo.SystemInfoGetPlatformString(KeyModelName, out modelName) != ErrorNone)
            {
                modelName = "";
                return false;
            }

            return true;
        }
    }
}
