﻿/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System.ComponentModel;
using System.Runtime.CompilerServices;
using TVMediaHub.Tizen.Models;
using TVMediaHub.Tizen.Utils;

namespace TVMediaHub.Tizen.ViewModels
{
    /// <summary>
    /// A class for ViewModel of TV MediaHub
    /// </summary>
    class MediaHubMainPageViewModel : INotifyPropertyChanged
    {
        /// <summary>
        /// A name of source
        /// </summary>
        public string SourceName { get; set; }

        private bool disableBackKeyHandler;

        public bool DisableBackKeyHandler
        {
            set
            {
                disableBackKeyHandler = value;
                OnPropertyChanged();
            }
            get => disableBackKeyHandler;
        }

        /// <summary>
        /// An event that is occurred when property of MediaHubMainPageViewModel is changed
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// A method for invoking PropertyChanged event
        /// </summary>
        /// <param name="propertyName">The name of property</param>
        protected void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;

            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        /// <summary>
        /// A consturctor
        /// Implements the SourceRemoveEventListener
        /// </summary>
        public MediaHubMainPageViewModel()
        {
            MediaHubImpl.GetInstance.StorageProviderInstance.SetSourceRemoveEventListener((sender, arg) =>
            {
                StorageInfoEventArgs e = arg as StorageInfoEventArgs;
                SourceName = e.storageName;
                OnPropertyChanged("SourceName");
            });
        }
    }
}
