﻿/*
* Copyright (c) 2017 Samsung Electronics Co., Ltd
*
* Licensed under the Flora License, Version 1.1 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://floralicense.org/license/
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

using System;
using Tizen.Xamarin.Forms.Extension;
using TVMediaHub.Tizen.Utils;
using TVMediaHub.Tizen.ViewModels;
using Xamarin.Forms;

namespace TVMediaHub.Tizen.Views
{
    /// <summary>
    /// A custom ContentPage for displaying the music player
    /// </summary>
    public partial class MusicPlayer : RelativeLayout
    {
        private bool IsInitailized;
        private Rectangle ShadowImageFocusedBounds;
        private Rectangle ShadowImageNormalBounds;

        private Rectangle AlbumImageFocusedBounds;
        private Rectangle AlbumImageNormalBounds;

        private Rectangle PausePlayButtonBounds;

        private Rectangle TitleBounds;
        private Rectangle ArtistBounds;
        private Rectangle AlbumNameBounds;

        /// <summary>
        /// Gets FocusArea for focus chain
        /// </summary>
        public Button GetFocusArea()
        {
            return MusicPlayerFocusArea;
        }

        /// <summary>
        /// A constructor
        /// </summary>
        public MusicPlayer()
        {
            BindingContext = MusicPlayerViewModelLocator.ViewModel;
            IsInitailized = false;
            InitializeComponent();
            InitializeSize();
        }

        private void MusicPlayerFocusAreaFocused(object sender, FocusEventArgs e)
        {
            MusicPlayerShadowImage.LayoutTo(ShadowImageFocusedBounds);
            MusicPlayerAlbumArt.LayoutTo(AlbumImageFocusedBounds);
        }

        private void MusicPlayerFocusAreaUnfocused(object sender, FocusEventArgs e)
        {
            MusicPlayerShadowImage.LayoutTo(ShadowImageNormalBounds);
            MusicPlayerAlbumArt.LayoutTo(AlbumImageNormalBounds);
        }

        private void InitializeSize()
        {
            WidthRequest = SizeUtils.GetWidthSize(546);
            HeightRequest = SizeUtils.GetHeightSize(546);
            Margin = new Thickness(SizeUtils.GetWidthSize(-14), SizeUtils.GetHeightSize(-14), 0, 0);


            MusicPlayerShadowImage.BorderTop = SizeUtils.GetHeightSize(67);
            MusicPlayerShadowImage.BorderBottom = SizeUtils.GetHeightSize(67);
            MusicPlayerShadowImage.BorderLeft = SizeUtils.GetWidthSize(67);
            MusicPlayerShadowImage.BorderRight = SizeUtils.GetWidthSize(67);

            ShadowImageFocusedBounds = new Rectangle(0, 0, SizeUtils.GetWidthSize(546), SizeUtils.GetHeightSize(546));
            ShadowImageNormalBounds = new Rectangle(SizeUtils.GetWidthSize(6), SizeUtils.GetHeightSize(6), SizeUtils.GetWidthSize(532), SizeUtils.GetHeightSize(532));

            AlbumImageFocusedBounds = new Rectangle(SizeUtils.GetWidthSize(64), SizeUtils.GetHeightSize(64), SizeUtils.GetWidthSize(418), SizeUtils.GetHeightSize(418));
            AlbumImageNormalBounds = new Rectangle(SizeUtils.GetWidthSize(70), SizeUtils.GetHeightSize(70), SizeUtils.GetWidthSize(406), SizeUtils.GetHeightSize(406));

            PausePlayButtonBounds = new Rectangle(SizeUtils.GetWidthSize(223), SizeUtils.GetHeightSize(223), SizeUtils.GetWidthSize(100), SizeUtils.GetHeightSize(100));

            TitleBounds = new Rectangle(SizeUtils.GetWidthSize(72), SizeUtils.GetHeightSize(498), SizeUtils.GetWidthSize(406), SizeUtils.GetHeightSize(32));
            ArtistBounds = new Rectangle(SizeUtils.GetWidthSize(72), SizeUtils.GetHeightSize(542), SizeUtils.GetWidthSize(418), SizeUtils.GetHeightSize(28));
            AlbumNameBounds = new Rectangle(SizeUtils.GetWidthSize(72), SizeUtils.GetHeightSize(572), SizeUtils.GetWidthSize(418), SizeUtils.GetHeightSize(28));

            MusicPlayerTitle.FontSize = SizeUtils.GetFontSize(28);

            MusicPlayerArtist.FontSize = SizeUtils.GetFontSize(24);
            MusicPlayerArtist.Opacity = 0.5;

            MusicPlayerAlbum.FontSize = SizeUtils.GetFontSize(24);
            MusicPlayerAlbum.Opacity = 0.25;
        }

        protected override void LayoutChildren(double x, double y, double width, double height)
        {
            if (IsInitailized == false)
            {
                base.LayoutChildren(x, y, width, height);
                MusicPlayerAlbumArt.Layout(AlbumImageNormalBounds);
                MusicPlayerTitle.Layout(TitleBounds);
                MusicPlayerArtist.Layout(ArtistBounds);
                MusicPlayerAlbum.Layout(AlbumNameBounds);
                MusicPlayerShadowImage.Layout(ShadowImageNormalBounds);
                MusicPlayerPausePlayButton.Layout(PausePlayButtonBounds);
                MusicPlayerFocusArea.Layout(PausePlayButtonBounds);
                IsInitailized = true;
            }
        }
    }
}
